<?php
if ( ! defined( 'ABSPATH' ) ) {
	error_log("EXITING");
	exit; // Exit if accessed directly.
}

/**
 * WordPress settings API class
 *
 */
if ( ! class_exists( 'WeDevs_Settings_API_Test' ) ) {
	class DKS_Settings {
		const OPTION_NAME = 'dks';

		/**
		 * @var WeDevs_Settings_API
		 */
		private $settings_api;
		private $page_title;
		private $menu_title;
		private $menu_slug;

		function __construct( $page_title, $menu_title, $menu_slug ) {
			$this->settings_api = new WeDevs_Settings_API;
			$this->menu_title   = $menu_title;
			$this->menu_slug    = $menu_slug;
			$this->page_title   = $page_title;
			add_action( 'admin_init', array( $this, 'admin_init' ) );
			add_action( 'admin_menu', array( $this, 'admin_menu' ) );
		}

		function admin_init() {
			//set the settings
			$this->settings_api->set_sections( $this->get_settings_sections() );
			$this->settings_api->set_fields( $this->get_settings_fields() );

			//initialize settings
			$this->settings_api->admin_init();
//			$this->set_default_settings();

			// Initialize Script for dynamic DKS State determination
			wp_enqueue_script('determine-dks-state', plugins_url('js/determine-dks-state.js', __FILE__), [], '1.0.0', ['strategy' => 'defer']);

			$proxyScriptURL = substr(dirname(__FILE__), 0, -strlen('includes')) . '/dks-api-proxy.php';
			wp_localize_script('determine-dks-state', 'dks_state', array(
				'plugin_directory' => plugins_url(basename($proxyScriptURL), $proxyScriptURL),
				'i18n' => array(
					'dksStateOK'   => __('The connection to the DKS is established.', 'dks'),
					'dksState401'  => __('Authentication to DKS failed (error code: 401)', 'dks'),
					'dksStateFail' => __('Connection to DKS failed.', 'dks')
				)
			));

			// Add CSS styles
			wp_enqueue_style('dks-admin-styles', plugins_url('css/dks-admin.css', __FILE__));
		}

		public function set_default_settings( $settings ) {
			$this->settings_api->set_fields( $settings );
		}

		function admin_menu() {
			add_options_page( $this->page_title, $this->menu_title, 'delete_posts', $this->menu_slug, array(
				$this,
				'plugin_page'
			) );
		}

		function get_settings_sections() {
			$sections = array(
				array(
					'id'    => self::OPTION_NAME,
					'title' => ''
				)
			);

			return $sections;
		}

		/**
		 * Returns all the settings fields
		 *
		 * @return array settings fields
		 */
		function get_settings_fields() {
			$settings_fields = array(
				'dks' => array(
					
					array(
						'name'              => 'server',
						'label'             => __( 'DKS Host', 'dks' ),
						'desc'              => __( 'URL of DKS', 'dks' ),
						'type'              => 'text',
						'default'           => 'http://dks',
						'sanitize_callback' => 'sanitize_text_field',
					),
					array(
						'name'              => 'apikey',
						'label'             => __( 'API Key', 'dks' ),
						'desc'              => __( 'API Key for access to secured DKS servers', 'dks' ),
						'type'              => 'text',
						'default'           => '',
						'sanitize_callback' => 'sanitize_text_field'
					),
					
					array(
						'name'    => 'propertySets',
						'label'   => __( 'Correction profiles', 'dks' ),
						'desc'    => __( 'Line by line specification of the correction profiles to be used.', 'dks' ),
						'type'    => 'textarea',
						'default' => 'base'
					),
					/*
					array(
						'name'    => 'slang',
						'label'   => __( 'Default Language', 'dks' ),
						'type'    => 'select',
						'options' => array(
							'de_DE' => 'Deutsch',
						),
						'default' => 'de_DE'
					),
					
					array(
						'name'    => 'styleForeign',
						'label'   => __( 'styleForeign', 'dks' ),
						'type'    => 'checkbox',
						'default' => 'on'
					),
					array(
						'name'    => 'styleOld',
						'label'   => __( 'styleOld', 'dks' ),
						'type'    => 'checkbox',
						'default' => 'on'
					),
					array(
						'name'    => 'styleRegional',
						'label'   => __( 'styleRegional', 'dks' ),
						'type'    => 'checkbox',
						'default' => 'on'
					),
					array(
						'name'    => 'styleColloquial',
						'label'   => __( 'styleColloquial', 'dks' ),
						'type'    => 'checkbox',
						'default' => 'on'
					),
					array(
						'name'    => 'styleFiller',
						'label'   => __( 'styleFiller', 'dks' ),
						'type'    => 'checkbox',
						'default' => 'on'
					),
					*/

				)
			);

			return apply_filters( 'wsc_admin_fields', $settings_fields );
		}

		function plugin_page() {
			echo '<div class="wrap">';
			echo "<h1>$this->page_title</h1>";
			echo "<div id='dks-connection-status'></div>";
			$this->settings_api->show_navigation();
			$this->settings_api->show_forms();
			echo '</div>';
		}

		/**
		 * Get all the pages
		 *
		 * @return array page names with key value pairs
		 */
		function get_pages() {
			$pages         = get_pages();
			$pages_options = array();
			if ( $pages ) {
				foreach ( $pages as $page ) {
					$pages_options[ $page->ID ] = $page->post_title;
				}
			}

			return $pages_options;
		}

	}

}